
from calibre.web.feeds.news import BasicNewsRecipe

class CommonDreams(BasicNewsRecipe):
    title          = u'Common Dreams'
    description    = u'Progressive news and views'
    __author__     = u'XanthanGum'
    language = 'en'

    oldest_article = 7
    max_articles_per_feed = 100
    
    feeds          = [
                       (u'Common Dreams Headlines', 
                       u'http://www.commondreams.org/feed/headlines_rss'), 
                       (u'Common Dreams Views', u'http://www.commondreams.org/feed/views_rss'), 
                       (u'Common Dreams Newswire', u'http://www.commondreams.org/feed/newswire_rss')
                       ]
